Enum Event

#[non_exhaustive]
pub enum Event { Ping { serial: u32, }, Configure { edges: WEnum<Resize>, width: i32, height: i32, }, PopupDone, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Ping

ping client

Ping a client to check if it is receiving events and sending requests. A client is expected to reply with a pong request.

Fields

serial: u32

serial number of the ping



Configure

suggest resize

The configure event asks the client to resize its surface.

The size is a hint, in the sense that the client is free to ignore it if it doesn’t resize, pick a smaller size (to satisfy aspect ratio or resize in steps of NxM pixels).

The edges parameter provides a hint about how the surface was resized. The client may use this information to decide how to adjust its content to the new size (e.g. a scrolling area might adjust its content position to leave the viewable content unmoved).

The client is free to dismiss all but the last configure event it received.

The width and height arguments specify the size of the window in surface-local coordinates.

Fields

edges: WEnum<Resize>

how the surface was resized

width: i32

new width of the surface

height: i32

new height of the surface



PopupDone

popup interaction is done

The popup_done event is sent out when a popup grab is broken, that is, when the user clicks a surface that doesn’t belong to the client owning the popup surface.

Implementations



impl Event

pub fn opcode(&self) -> u16

Get the opcode number of this message