Enum FullscreenMethod
#[non_exhaustive]#[repr(u32)]pub enum FullscreenMethod {
Default = 0,
Scale = 1,
Driver = 2,
Fill = 3,
}Available on crate feature
wayland and Linux only.Expand description
different method to set the surface fullscreen
Hints to indicate to the compositor how to deal with a conflict between the dimensions of the surface and the dimensions of the output. The compositor is free to ignore this parameter.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Default = 0
no preference, apply default policy
Scale = 1
scale, preserve the surface’s aspect ratio and center on output
Driver = 2
switch output mode to the smallest mode that can fit the surface, add black borders to compensate size mismatch
Fill = 3
no upscaling, center on output and add black borders to compensate size mismatch