Struct Resize
pub struct Resize(/* private fields */);wayland and Linux only.Expand description
edge values for resizing
These values are used to indicate which edge of a surface is being dragged in a resize operation. The server may use this information to adapt its behavior, e.g. choose an appropriate cursor image.
Implementations
impl Resize
impl Resize
pub const BottomLeft: Resize
pub const BottomLeft: Resize
bottom and left edges
pub const BottomRight: Resize
pub const BottomRight: Resize
bottom and right edges
impl Resize
impl Resize
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<Resize>
pub const fn from_bits(bits: u32) -> Option<Resize>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> Resize
pub const fn from_bits_truncate(bits: u32) -> Resize
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> Resize
pub const fn from_bits_retain(bits: u32) -> Resize
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Resize>
pub fn from_name(name: &str) -> Option<Resize>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: Resize) -> bool
pub const fn intersects(&self, other: Resize) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: Resize) -> bool
pub const fn contains(&self, other: Resize) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: Resize)
pub fn remove(&mut self, other: Resize)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn set(&mut self, other: Resize, value: bool)
pub fn set(&mut self, other: Resize, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Resize) -> Resize
pub const fn intersection(self, other: Resize) -> Resize
The bitwise and (&) of the bits in self and other.
pub const fn difference(self, other: Resize) -> Resize
pub const fn difference(self, other: Resize) -> Resize
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Resize) -> Resize
pub const fn symmetric_difference(self, other: Resize) -> Resize
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> Resize
pub const fn complement(self) -> Resize
The bitwise negation (!) of the bits in self, truncating the result.
impl Resize
impl Resize
pub const fn iter(&self) -> Iter<Resize>
pub const fn iter(&self) -> Iter<Resize>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<Resize>
pub const fn iter_names(&self) -> IterNames<Resize>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.