Struct Transient
pub struct Transient(/* private fields */);wayland and Linux only.Expand description
details of transient behaviour
These flags specify details of the expected behaviour of transient surfaces. Used in the set_transient request.
Implementations
impl Transient
impl Transient
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<Transient>
pub const fn from_bits(bits: u32) -> Option<Transient>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> Transient
pub const fn from_bits_truncate(bits: u32) -> Transient
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> Transient
pub const fn from_bits_retain(bits: u32) -> Transient
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Transient>
pub fn from_name(name: &str) -> Option<Transient>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: Transient) -> bool
pub const fn intersects(&self, other: Transient) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: Transient) -> bool
pub const fn contains(&self, other: Transient) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: Transient)
pub fn remove(&mut self, other: Transient)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: Transient)
pub fn toggle(&mut self, other: Transient)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: Transient, value: bool)
pub fn set(&mut self, other: Transient, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Transient) -> Transient
pub const fn intersection(self, other: Transient) -> Transient
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: Transient) -> Transient
pub const fn union(self, other: Transient) -> Transient
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: Transient) -> Transient
pub const fn difference(self, other: Transient) -> Transient
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Transient) -> Transient
pub const fn symmetric_difference(self, other: Transient) -> Transient
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> Transient
pub const fn complement(self) -> Transient
The bitwise negation (!) of the bits in self, truncating the result.
impl Transient
impl Transient
pub const fn iter(&self) -> Iter<Transient>
pub const fn iter(&self) -> Iter<Transient>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<Transient>
pub const fn iter_names(&self) -> IterNames<Transient>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.